@@ -51,7 +51,11 @@ infixr 1 ?:
 
 {- |
 Like the @?@ operator of the C progamming language.
-Example: @bool ?: ("yes", "no")@.
+
+>>> True ?: ("yes", "no")
+"yes"
+>>> False ?: ("yes", "no")
+"no"
 -}
 {-# INLINE (?:) #-}
 (?:) :: Bool -> (a,a) -> a
@@ -64,7 +68,9 @@ infixr 1 `implies`
 {- |
 Logical operator for implication.
 
-Funnily because of the ordering of 'Bool' it holds @implies == (<=)@.
+Funnily because of the ordering of 'Bool' it holds:
+
+prop> \a b -> implies a b == (a<=b)
 -}
 {-# INLINE implies #-}
 implies :: Bool -> Bool -> Bool
