@@ -26,7 +26,7 @@ import Prelude hiding (unzip, break, span, )
 -- >>> import Data.List (transpose)
 -- >>> import Data.Maybe.HT (toMaybe)
 -- >>> import Data.Maybe (mapMaybe, isNothing)
--- >>> import Data.Char (isLetter, toUpper)
+-- >>> import Data.Char (isLetter, isUpper, toUpper)
 -- >>> import Data.Eq.HT (equating)
 -- >>> import Control.Monad (liftM2)
 -- >>>
@@ -306,6 +306,11 @@ There is always a list for the part before the first leading character.
 It may be empty.
 See package @non-empty@ for more precise result type.
 
+>>> segmentBefore isUpper "AbcdXyz"
+["","Abcd","Xyz"]
+>>> segmentBefore isUpper "kAbcdXYZ"
+["k","Abcd","X","Y","Z"]
+
 prop> forAllPredicates $ \p xs -> concat (segmentBefore p xs) == xs
 prop> forAllPredicates $ \p xs -> length (filter p xs) == length (tail (segmentBefore p xs))
 prop> forAllPredicates $ \p -> all (p . head) . tail . segmentBefore p
