@@ -2,6 +2,8 @@ module Data.List.Match (
    L.take,
    L.drop,
    L.splitAt,
+   L.takeRev,
+   L.dropRev,
    L.replicate,
    L.equalLength,
    L.compareLength,
