@@ -14,6 +14,10 @@ mapFst f (a,b) = (f a, b)
 mapSnd :: (b -> c) -> (a,b) -> (a,c)
 mapSnd f (a,b) = (a, f b)
 
+{-# INLINE zipPair #-}
+zipPair :: (a,b) -> (c,d) -> ((a,c),(b,d))
+zipPair (a,b) (c,d) = ((a,c),(b,d))
+
 {-# INLINE zipWithPair #-}
 zipWithPair :: (a -> c -> e, b -> d -> f) -> (a,b) -> (c,d) -> (e,f)
 zipWithPair (e,f) (a,b) (c,d) = (e a c, f b d)
